#! /bin/sh
# BUGS
#    - runs under root UID.

VOICEMAIL_SPOOL=/var/spool/voice/mailboxes
PVF_TOOLS_DIR=/usr/bin
SAY_RSYNTH_EXECUTABLE=/usr/bin/say
PVF_MODEM_FILTER='pvftormd ZyXEL_1496 2'
PVF_CUT="$PVF_TOOLS_DIR/pvfcut -H -0.5 -T -0.5"
PVF_AMP="$PVF_TOOLS_DIR/pvfamp -A 3.5"


# SYNOPSIS
#    result = say_something(text, file)
# RESULT
#       - OK
#       - ERROR
# DESCRIPTION
#    This function uses rsynth, sox and convert_au.sh
#    to convert a text to its file representation.
#    This is slow and should only be used for
#    texts which must be generated and spoken.
# MODIFIES
# BUGS
#    - use of tmp file not unique. patch to rsynth would be needed. We
#      thus create a tmp dir.
#    - security bug created by this, see $?
# NOTE
#    - This function does not use vgetty
#    - Outputs to stderr removed (caused problems)
#    - pvfcut to allow hearing of last part of message with ZyXEL.
# SOURCE
#    mvm 1.1 PV002 of 12/04/97
#    modified for RedHat paths
function saysomething {
   mkdir tmp_$$
   if [ $? = 0 ]; then
   cd tmp_$$
   touch tmp
   $SAY_RSYNTH_EXECUTABLE -r 9600 -a -l tmp-msg "$1" 1>&2
   $PVF_TOOLS_DIR/lintopvf < tmp-msg -I -S -W -s 9600 | $PVF_CUT | $PVF_AMP | $PVF_TOOLS_DIR/$PVF_MODEM_FILTER > $2
   cd ..
   rm -rf tmp_$$
   fi
   echo "OK"
}

if [ $# != 1 ]; then
   echo "$0 [0-9]+"
   echo "$0: bad args."
   exit 2
fi

case $1 in
   [0-9]*) ;;
   *) echo "Not an numerical argument $1. Must be [0-9]+."
      exit 2;;
esac

if [ -f $VOICEMAIL_SPOOL/$1/.password ]; then
   MAILFILE="$VOICEMAIL_SPOOL/$1/msg_`date '+%y%m%d%H%M%S'`_from_-1_$$"
   TMPFILE=/tmp/truc1_$$
   awk 'BEGIN { skip = 1; }
        /^From: / { print "Mail from";
                    for (i = 2; i <= NF; i++) {
                       printf "%s ", $i;
                    }
                    print "";
                  }
        { if (NF == 0) {
             skip = 0;
          }
          else if (skip == 0) {
             print;
          }
        }' > $TMPFILE
   saysomething "`cat $TMPFILE`" $MAILFILE
   rm $TMPFILE
else
   echo "Unknown voicemail user $1."
   exit 1
fi

exit 0
